summaryrefslogtreecommitdiff
path: root/common/fmap.c
diff options
context:
space:
mode:
Diffstat (limited to 'common/fmap.c')
-rw-r--r--common/fmap.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/common/fmap.c b/common/fmap.c
index 6f84c37b63..9ddd670fd4 100644
--- a/common/fmap.c
+++ b/common/fmap.c
@@ -109,9 +109,9 @@ const struct _ec_fmap {
.area_name = "RO_FRID",
.area_offset = CONFIG_EC_PROTECTED_STORAGE_OFF -
FMAP_REGION_START + CONFIG_RO_STORAGE_OFF +
- RELATIVE_RO((uint32_t)__version_struct_offset) +
- offsetof(struct version_struct, version),
- .area_size = sizeof(version_data.version),
+ RELATIVE_RO((uint32_t)__image_data_offset) +
+ offsetof(struct image_data, version),
+ .area_size = sizeof(current_image_data.version),
.area_flags = FMAP_AREA_STATIC | FMAP_AREA_RO,
},
@@ -151,15 +151,15 @@ const struct _ec_fmap {
* RW firmware version ID. Must be NULL terminated
* ASCII, and padded with \0.
* TODO: Get the relative offset of
* __version_struct_offset within our RW image to
* accommodate image asymmetry.
*/
.area_name = "RW_FWID",
.area_offset = CONFIG_EC_WRITABLE_STORAGE_OFF -
FMAP_REGION_START + CONFIG_RW_STORAGE_OFF +
- RELATIVE_RO((uint32_t)__version_struct_offset) +
- offsetof(struct version_struct, version),
- .area_size = sizeof(version_data.version),
+ RELATIVE_RO((uint32_t)__image_data_offset) +
+ offsetof(struct image_data, version),
+ .area_size = sizeof(current_image_data.version),
.area_flags = FMAP_AREA_STATIC,
},
}
@@ -151,15 +151,15 @@ const struct _ec_fmap {
* ASCII, and padded with \0.
* TODO: Get the relative offset of
- * __version_struct_offset within our RW image to
+ * __image_data_offset within our RW image to
* accommodate image asymmetry.
*/